==> haskell-ranged-sets-0.5.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Ranged-sets
version:              0.5.0
visibility:           public
id:                   Ranged-sets-0.5.0-JLMFjUwRjti2m2aUsVRiTR
key:                  Ranged-sets-0.5.0-JLMFjUwRjti2m2aUsVRiTR
license:              BSD-3-Clause
copyright:            Paul Johnson, 2005, 2006, 2007, 2008, 2019, 2025
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Ranged-sets
synopsis:             Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:

    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)

    Alternatively you can have all strings s such that:

    >    ("F" <= s < "G")

category:             Data
abi:                  0140a5649c789c9c22a113c98044e1d6
exposed:              True
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges

import-dirs:          /usr/lib/ghc-9.4.8/site-local/Ranged-sets-0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Ranged-sets-0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Ranged-sets-0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ranged-sets
hs-libraries:         HSRanged-sets-0.5.0-JLMFjUwRjti2m2aUsVRiTR
depends:              QuickCheck-2.14.3-KBQtot6OiBttU8xgKWkQ base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html:         /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ranged-sets-0.5.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Ranged-sets
version:              0.5.0
visibility:           public
id:                   Ranged-sets-0.5.0-IMONu2d0QDt3jQipyqb3Rn
key:                  Ranged-sets-0.5.0-IMONu2d0QDt3jQipyqb3Rn
license:              BSD-3-Clause
copyright:            Paul Johnson, 2005, 2006, 2007, 2008, 2019, 2025
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Ranged-sets
synopsis:             Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:

    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)

    Alternatively you can have all strings s such that:

    >    ("F" <= s < "G")

category:             Data
abi:                  02d8bf67fa1c6ea42fb79e47c1b3d2c2
exposed:              True
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges

import-dirs:          /usr/lib/ghc-9.4.8/site-local/Ranged-sets-0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Ranged-sets-0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Ranged-sets-0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ranged-sets
hs-libraries:         HSRanged-sets-0.5.0-IMONu2d0QDt3jQipyqb3Rn
depends:
    QuickCheck-2.14.3-3S3WOBL6rHa3L0CMYI1WVh base-4.17.2.1

haddock-interfaces:   /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html:         /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
